import React from 'react';
import PropTypes from 'prop-types';
import makeEventProps from 'make-event-props';
import Calendar from 'react-calendar';
import type { ClassName, CloseReason, Detail, LooseValue, OpenReason, Value } from './shared/types';
type Icon = React.ReactElement | string;
type IconOrRenderFunction = Icon | React.ComponentType | React.ReactElement;
type CalendarProps = Omit<React.ComponentPropsWithoutRef<typeof Calendar>, 'className' | 'maxDetail' | 'onChange'>;
type EventProps = ReturnType<typeof makeEventProps>;
export type DatePickerProps = {
    autoFocus?: boolean;
    calendarAriaLabel?: string;
    calendarClassName?: ClassName;
    calendarIcon?: IconOrRenderFunction | null;
    className?: ClassName;
    clearAriaLabel?: string;
    clearIcon?: IconOrRenderFunction | null;
    closeCalendar?: boolean;
    'data-testid'?: string;
    dayAriaLabel?: string;
    dayPlaceholder?: string;
    disableCalendar?: boolean;
    disabled?: boolean;
    format?: string;
    id?: string;
    isOpen?: boolean;
    locale?: string;
    maxDate?: Date;
    maxDetail?: Detail;
    minDate?: Date;
    monthAriaLabel?: string;
    monthPlaceholder?: string;
    name?: string;
    nativeInputAriaLabel?: string;
    onCalendarClose?: () => void;
    onCalendarOpen?: () => void;
    onChange?: (value: Value) => void;
    onFocus?: (event: React.FocusEvent<HTMLDivElement>) => void;
    onInvalidChange?: () => void;
    openCalendarOnFocus?: boolean;
    portalContainer?: HTMLElement | null;
    required?: boolean;
    returnValue?: 'start' | 'end' | 'range';
    shouldCloseCalendar?: (props: {
        reason: CloseReason;
    }) => boolean;
    shouldOpenCalendar?: (props: {
        reason: OpenReason;
    }) => boolean;
    showLeadingZeros?: boolean;
    value?: LooseValue;
    yearAriaLabel?: string;
    yearPlaceholder?: string;
} & CalendarProps & Omit<EventProps, 'onChange' | 'onFocus'>;
declare function DatePicker(props: DatePickerProps): JSX.Element;
declare namespace DatePicker {
    var propTypes: {
        autoFocus: PropTypes.Requireable<boolean>;
        calendarAriaLabel: PropTypes.Requireable<string>;
        calendarClassName: PropTypes.Requireable<NonNullable<string | (string | null | undefined)[] | null | undefined>>;
        calendarIcon: PropTypes.Requireable<NonNullable<PropTypes.ReactNodeLike | ((...args: any[]) => any)>>;
        className: PropTypes.Requireable<NonNullable<string | (string | null | undefined)[] | null | undefined>>;
        clearAriaLabel: PropTypes.Requireable<string>;
        clearIcon: PropTypes.Requireable<NonNullable<PropTypes.ReactNodeLike | ((...args: any[]) => any)>>;
        closeCalendar: PropTypes.Requireable<boolean>;
        'data-testid': PropTypes.Requireable<string>;
        dayAriaLabel: PropTypes.Requireable<string>;
        dayPlaceholder: PropTypes.Requireable<string>;
        disableCalendar: PropTypes.Requireable<boolean>;
        disabled: PropTypes.Requireable<boolean>;
        format: PropTypes.Requireable<string>;
        id: PropTypes.Requireable<string>;
        isOpen: PropTypes.Requireable<boolean>;
        locale: PropTypes.Requireable<string>;
        maxDate: PropTypes.Validator<Date | null | undefined>;
        maxDetail: PropTypes.Requireable<"month" | "year" | "century" | "decade">;
        minDate: PropTypes.Validator<Date | null | undefined>;
        monthAriaLabel: PropTypes.Requireable<string>;
        monthPlaceholder: PropTypes.Requireable<string>;
        name: PropTypes.Requireable<string>;
        nativeInputAriaLabel: PropTypes.Requireable<string>;
        onCalendarClose: PropTypes.Requireable<(...args: any[]) => any>;
        onCalendarOpen: PropTypes.Requireable<(...args: any[]) => any>;
        onChange: PropTypes.Requireable<(...args: any[]) => any>;
        onFocus: PropTypes.Requireable<(...args: any[]) => any>;
        openCalendarOnFocus: PropTypes.Requireable<boolean>;
        portalContainer: PropTypes.Requireable<object>;
        required: PropTypes.Requireable<boolean>;
        returnValue: PropTypes.Requireable<string>;
        showLeadingZeros: PropTypes.Requireable<boolean>;
        value: PropTypes.Requireable<NonNullable<NonNullable<string | Date | null | undefined> | import("./shared/types").Range<NonNullable<string | Date | null | undefined>> | null | undefined>>;
        yearAriaLabel: PropTypes.Requireable<string>;
        yearPlaceholder: PropTypes.Requireable<string>;
    };
}
export default DatePicker;
